#[non_exhaustive]pub enum BuildError {
VirtualManifest(PathBuf),
General(String),
BuildRustdocJsonError,
CapturedOutputError(String),
CommandExecutionError(String),
CargoManifestError(Error),
CargoMetadataError(Error),
IoError(Error),
}Expand description
Represents all errors that can occur when using Builder::build().
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
VirtualManifest(PathBuf)
You tried to generate rustdoc JSON for a virtual manifest. That does not work. You need to point to the manifest of a real package.
General(String)
A general error. Refer to the attached error message for more info.
BuildRustdocJsonError
An error originating from building the rustdoc JSON for a crate.
In this case the user will see the exact errors on stderr, regardless of
if stderr was printed to the terminal or captured with
Builder::build_with_captured_output().
CapturedOutputError(String)
Occurs when stdout or stderr could not be captured when using
Builder::build_with_captured_output()).
CommandExecutionError(String)
Occurs when a command could not be executed, e.g. because the binary that we tried to run did not exist.
CargoManifestError(Error)
An error originating from cargo-manifest.
CargoMetadataError(Error)
An error originating from cargo_metadata.
IoError(Error)
Some kind of IO error occurred.